@@ -1,7 +1,9 @@
 """DLsite Async."""
-from . import exceptions, utils
+from . import exceptions
 from .api import DlsiteAPI
 from .circle import Circle, MakerType
+from .play.api import PlayAPI
+from .utils import find_maker_id, find_product_id
 from .work import AgeCategory, BookType, Work, WorkType
 
 
@@ -11,8 +13,10 @@ __all__ = [
     "Circle",
     "DlsiteAPI",
     "MakerType",
+    "PlayAPI",
     "Work",
     "WorkType",
     "exceptions",
-    "utils",
+    "find_maker_id",
+    "find_product_id",
 ]
