@@ -1,7 +1,8 @@
 """DLsite circle classes."""
+from collections.abc import Mapping
 from dataclasses import dataclass, fields
 from enum import Enum
-from typing import Any, Mapping
+from typing import Any
 
 from .exceptions import InvalidIDError
 
